#
# steering, Programme/schedule management for AURA
#
# Copyright (C) 2017-2018, Ingo Leindecker
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.models import User

from .models import Profile


class ProfileInline(admin.StackedInline):
    model = Profile
    can_delete = False
    verbose_name_plural = "Profile"
    fk_name = "user"


class ProfileUserAdmin(UserAdmin):
    inlines = (ProfileInline,)

    def get_queryset(self, request):
        """Let common users only edit their own profile"""
        if not request.user.is_superuser:
            return (
                super(UserAdmin, self).get_queryset(request).filter(pk=request.user.id)
            )

        return super(UserAdmin, self).get_queryset(request)

    def get_readonly_fields(self, request, obj=None):
        """Limit field access for common users"""
        if not request.user.is_superuser:
            return (
                "username",
                "is_staff",
                "is_superuser",
                "is_active",
                "date_joined",
                "last_login",
                "groups",
                "user_permissions",
            )
        return list()

    def get_inline_instances(self, request, obj=None):
        """Append profile fields to UserAdmin"""
        if not obj:
            return list()

        return super(ProfileUserAdmin, self).get_inline_instances(request, obj)


admin.site.unregister(User)
admin.site.register(User, ProfileUserAdmin)
